@@ -38,7 +38,6 @@ class SourceDevice:
         self.serial_number = None
         self.error_list = []
 
-
     @property
     def hostname(self):
         return f'{self.device_name}.{self.site_name}'
@@ -54,7 +53,6 @@ class SourceDevice:
         self.device_name = None
         self.site_name = None
 
-
     @property
     def device_type(self):
         if re.match(r'^swc1', self.log_filename):
@@ -114,15 +112,14 @@ class SourceDevice:
                         startup_config.update({index: line.strip()})
                 else:
                     continue
-
+        return startup_config
 
     def is_valid_filename(self, regex: re.Pattern):
         match = re.match(regex, self.log_filename)
-        if match == None:
+        if match is None:
             match = False
         return match
 
-
     def check_device_net_info(self, ip_info: dict):
         error_codes = {
             1: 'does not have the correct IP address.',
@@ -132,18 +129,18 @@ class SourceDevice:
 
         error = []
         if self.ip.rsplit('.', 1)[1] == ip_info[self.device_name] \
-           and self.netmask == ip_info['netmask'] \
-           and self.gateway.rsplit('.', 1)[1] == ip_info['gw']:
+                and self.netmask == ip_info['netmask'] \
+                and self.gateway.rsplit('.', 1)[1] == ip_info['gw']:
             return
         if self.ip.rsplit('.', 1)[1] != ip_info[self.device_name]:
             error.append(f'{self.hostname} ' +
-                        error_codes[1] + '\nCurrent: {}'.format(self.ip))
+                         error_codes[1] + '\nCurrent: {}'.format(self.ip))
         if self.netmask != ip_info['netmask']:
             error.append(f'{self.hostname} ' +
-                        error_codes[2] + '\nCurrent: {}'.format(self.netmask))
+                         error_codes[2] + '\nCurrent: {}'.format(self.netmask))
         if self.gateway.rsplit('.', 1)[1] != ip_info['gw']:
             error.append(f'{self.hostname} ' +
-                        error_codes[3] + '\nCurrent: {}'.format(self.gateway))
+                         error_codes[3] + '\nCurrent: {}'.format(self.gateway))
         return error
 
 
@@ -187,41 +184,43 @@ class ReferenceInformation:
         # Due to a config adjustment adding TACACs and AAA after these sites left - RL 3/2
         if site_name in ['0489', '2352']:
             self.startup_config = {
-                # Takes cell value, strips leading white space characters, and creates a list of these values to assign them to a keyword for calling later
-                'core1': [x.value.strip() for x in wb['core']['A'] if x.value != None and '!' not in x.value],
-                'core2': [x.value.strip() for x in wb['core']['B'] if x.value != None and '!' not in x.value],
+                # Takes cell value, strips leading white space characters, and creates a list of these values to
+                # assign them to a keyword for calling later
+                'core1' : [x.value.strip() for x in wb['core']['A'] if x.value != None and '!' not in x.value],
+                'core2' : [x.value.strip() for x in wb['core']['B'] if x.value != None and '!' not in x.value],
                 'access': [x.value.strip() for x in wb['access']['A'] if x.value != None and '!' not in x.value],
-                'spare': [x.value.strip() for x in wb['spare']['A'] if x.value != None and '!' not in x.value],
-                'show': [x.value.strip() for x in wb['show']['A'] if x.value != None and '!' not in x.value]
+                'spare' : [x.value.strip() for x in wb['spare']['A'] if x.value != None and '!' not in x.value],
+                'show'  : [x.value.strip() for x in wb['show']['A'] if x.value != None and '!' not in x.value]
             }
         else:
             self.startup_config = {
-                # Takes cell value, strips leading white space characters, and creates a list of these values to assign them to a keyword for calling later
-                'core1': [x.value.strip() for x in wb['core']['C'] if x.value != None and '!' not in x.value],
-                'core2': [x.value.strip() for x in wb['core']['D'] if x.value != None and '!' not in x.value],
+                # Takes cell value, strips leading white space characters, and creates a list of these values to
+                # assign them to a keyword for calling later
+                'core1' : [x.value.strip() for x in wb['core']['C'] if x.value != None and '!' not in x.value],
+                'core2' : [x.value.strip() for x in wb['core']['D'] if x.value != None and '!' not in x.value],
                 'access': [x.value.strip() for x in wb['access']['B'] if x.value != None and '!' not in x.value],
-                'spare': [x.value.strip() for x in wb['spare']['A'] if x.value != None and '!' not in x.value],
-                'show': [x.value.strip() for x in wb['show']['A'] if x.value != None and '!' not in x.value]
+                'spare' : [x.value.strip() for x in wb['spare']['A'] if x.value != None and '!' not in x.value],
+                'show'  : [x.value.strip() for x in wb['show']['A'] if x.value != None and '!' not in x.value]
             }
         return self.startup_config
 
     def update_reference_show_log(self, dev_hostname: str):
-        show_dict={
-            'show_inv': '',
-            'show_ver': '',
-            'show_env': '',
-            'show_vlan': '',
-            'show_license': '',
-            'show_dir': '',
+        show_dict = {
+            'show_inv'           : '',
+            'show_ver'           : '',
+            'show_env'           : '',
+            'show_vlan'          : '',
+            'show_license'       : '',
+            'show_dir'           : '',
             'show_install_active': ''
         }
 
         with open(self.log_file_path, mode='r', encoding='UTF-8-sig') as sf:
-            read_show=sf.read()
-            read_show=re.sub(r'<HOSTNAME>', dev_hostname, read_show)
-            show_regex_list=[re.compile(x.strip())
-                            for x in read_show.split('!!!')]
-            show_dict=dict(zip(show_dict.keys(), show_regex_list))
+            read_show = sf.read()
+            read_show = re.sub(r'<HOSTNAME>', dev_hostname, read_show)
+            show_regex_list = [re.compile(x.strip())
+                               for x in read_show.split('!!!')]
+            show_dict = dict(zip(show_dict.keys(), show_regex_list))
 
         return show_dict
 
@@ -230,47 +229,46 @@ class ReferenceInformation:
         Takes an existing reference configuration template and populates it with device specific information
         in order to check against a correct, expected value.
         """
-        sourceList=self.startup_config[source_device.device_type]
-        unique_source_list=[]
+        sourceList = self.startup_config[source_device.device_type]
+        unique_source_list = []
 
         for line in sourceList:
             if '!' in line:
                 continue
             if '<STORE>' in line:
                 unique_source_list.append(line.replace(
-                    '<STORE>', source_device.site_name))
+                        '<STORE>', source_device.site_name))
                 continue
             if '<HOSTNAME>' in line:
                 unique_source_list.append(line.replace(
-                    '<HOSTNAME>', source_device.hostname))
+                        '<HOSTNAME>', source_device.hostname))
                 continue
             if all(substring in line for substring in ['<IP>', '<SUBNET>']):
                 unique_source_list.append(
-                    line.replace('<IP>', source_device.ip).replace('<SUBNET>', source_device.netmask))
+                        line.replace('<IP>', source_device.ip).replace('<SUBNET>', source_device.netmask))
                 continue
             if '<GATEWAY>' in line:
                 unique_source_list.append(line.replace(
-                    '<GATEWAY>', source_device.gateway))
+                        '<GATEWAY>', source_device.gateway))
                 continue
             unique_source_list.append(line)
 
         return unique_source_list
 
 
-
 def list_site_info(filepath: Path):
     """
     Scans QA directory tree for branches containing log files
     """
     if filepath.name.split(' ')[0] == 'POC':
-        site_name=filepath.name.split(' ')[1][-4:]
+        site_name = filepath.name.split(' ')[1][-4:]
     else:
-        site_name=filepath.name.split(' ')[0][-4:]
+        site_name = filepath.name.split(' ')[0][-4:]
     for branch in filepath.iterdir():
         if branch.is_dir() and 'QA' in branch.name:
-            branch_info=(str(site_name), Path(branch))
+            branch_info = (str(site_name), Path(branch))
         else:
-            branch_info=(str(site_name), Path(filepath))
+            branch_info = (str(site_name), Path(filepath))
 
     return branch_info
 
@@ -285,7 +283,7 @@ def find_log_differences(target_list: list, reference_list: list):
     Uses difflib to generate delta objects after comparing contents of two files.
     Read more about how difflib does this here: https://docs.python.org/3/library/difflib.html
     """
-    diff=unified_diff(reference_list, target_list,
+    diff = unified_diff(reference_list, target_list,
                         fromfile='reference', tofile='target', n=0)
     target_diff = []
 
@@ -300,22 +298,22 @@ def add_reference_cert_id(target_diff_list: list, source_device: SourceDevice):
     """
     Adds the TrustPoint Self Signed certificate information to the reference configuration
     """
-    token_id_pattern=re.compile(
-        r'crypto pki trustpoint TP-self-signed-(?P<SelfSignedID>[0-9]{8,10})$')
-    match_token_id=list(token_id_pattern.search(x).group('SelfSignedID')
+    token_id_pattern = re.compile(
+            r'crypto pki trustpoint TP-self-signed-(?P<SelfSignedID>[0-9]{8,10})$')
+    match_token_id = list(token_id_pattern.search(x).group('SelfSignedID')
                           for x in target_diff_list if token_id_pattern.search(x))
 
-    regex_list=[re.compile(x) for x in (r'Using [0-9]{4,5} out of 2097152 bytes',
-                  r'certificate self-signed 01 nvram:IOS-Self-Sig#[0-9].cer',
-                  r'username cisco privilege 15 secret 9 [^ \t\n\r\f\v]{61}$',
-                  r'enable secret 9 [^ \t\n\r\f\v]{61}$',
-                  r'ntp authentication-key 40 md5 [A-Z0-9]{18} 7',
-                  r'certificate ca 01 nvram:CiscoLicensi#[0-9]CA.cer',
-                  r'client 172.26.202.21 server-key 7 [0-9A-Z]{22}',
-                  r'client 172.29.202.21 server-key 7 [0-9A-Z]{22}',
-                  r'memory free low-watermark processor 22917|memory free low-watermark processor 87534')]
+    regex_list = [re.compile(x) for x in (r'Using [0-9]{4,5} out of 2097152 bytes',
+                                          r'certificate self-signed 01 nvram:IOS-Self-Sig#[0-9].cer',
+                                          r'username cisco privilege 15 secret 9 [^ \t\n\r\f\v]{61}$',
+                                          r'enable secret 9 [^ \t\n\r\f\v]{61}$',
+                                          r'ntp authentication-key 40 md5 [A-Z0-9]{18} 7',
+                                          r'certificate ca 01 nvram:CiscoLicensi#[0-9]CA.cer',
+                                          r'client 172.26.202.21 server-key 7 [0-9A-Z]{22}',
+                                          r'client 172.29.202.21 server-key 7 [0-9A-Z]{22}',
+                                          r'memory free low-watermark processor 22917|memory free low-watermark processor 87534')]
 
-    token_id_regex_list=[r'crypto pki trustpoint TP-self-signed-##########',
+    token_id_regex_list = [r'crypto pki trustpoint TP-self-signed-##########',
                            r'subject-name cn=IOS-Self-Signed-Certificate-##########',
                            r'rsakeypair TP-self-signed-##########',
                            r'crypto pki certificate chain TP-self-signed-##########']
@@ -337,7 +335,7 @@ def compare_log_crypto(target_difference_list: list, crypto_regex_list: list):
     Checks unique crypto hashes to ensure they are in the correct format and contain the correct characters before
     accepting them as correct.
     """
-    issues_list=[]
+    issues_list = []
     for difference in target_difference_list:
         print(f'\nChecking for match with {difference}...\n')
         if any([re.match(regex, difference) for regex in crypto_regex_list]):
@@ -350,11 +348,12 @@ def compare_log_crypto(target_difference_list: list, crypto_regex_list: list):
     return issues_list
 
 
-def send_html_email(from_address: str, to_addresses: list, subject: str, filepath: Path, message: str, mail_server='mailhost.wwt.com', port=25):
-    msg=EmailMessage()
-    msg['Subject']=subject
-    msg['From']=from_address
-    msg['To']=to_addresses
+def send_html_email(from_address: str, to_addresses: list, subject: str, filepath: Path, message: str,
+                    mail_server='mailhost.wwt.com', port=25):
+    msg = EmailMessage()
+    msg['Subject'] = subject
+    msg['From'] = from_address
+    msg['To'] = to_addresses
     msg.set_content(message, subtype='html')
     try:
         with SMTP(host=mail_server, port=port) as smtpObj:
@@ -367,7 +366,7 @@ def send_html_email(from_address: str, to_addresses: list, subject: str, filepat
 
 
 def autobot_love():
-    love=('<code>'
+    love = ('<code>'
             r'|        o      |<br>'
             r'|   _____|__    |<br>'
             r'|  (O   O)  )   |<br>'
@@ -380,4 +379,3 @@ def autobot_love():
             '</code>'
             )
     return love
-
